@@ -64,6 +64,7 @@ class DiscreteEnv(gym.Env):
 
     #introduce some (short) length (time steps)
     self.horizon=200
+    self.are_we_done = False
     
     
 
@@ -78,10 +79,9 @@ class DiscreteEnv(gym.Env):
 #"action" argument is one value in the range of the action space (logit transform)
   def step(self, action):
     
-    #check if horizon is over, otherwise keep on doing
-    end = bool(self.horizon <= 0)
-    if end:
-        done = True
+    #check if horizon is over, otherwise keep on going
+    if self.horizon <= 0:
+        self.are_we_done = True
       
     data = []
     for self.state in self.dfa.itertuples(index=False):    #self.df.itertuples(index=False):
@@ -120,11 +120,12 @@ class DiscreteEnv(gym.Env):
     #set placeholder for infos
     info ={}        
      
-    return self.state, reward, done, theta_updated , {}
+    return self.state, reward, self.are_we_done, theta_updated , {}
 
 #reset state and horizon    
   def reset(self):
     self.horizon = 200
+    self.are_we_done = False
     
     self.dfa = pd.DataFrame(dict(
             Xsa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
